@@ -17,6 +17,7 @@ use Scalar::Util qw(reftype);
 our $ENCODE_UTF8   = 1;
 our $SANITIZE_UTF8 = 1;
 our $FORCE_UNTAINT = 1;
+our $PRESERVE_UTF8 = 0;
 
 =head1 Methods
 
@@ -111,8 +112,8 @@ sub bind {
 
 sub DESTROY {
     my ($self) = @_;
-    $self->{engine}->_destroy();
-    $self->{runtime}->_destroy();
+    $self->{engine}->_destroy() if $self->{engine};
+    $self->{runtime}->_destroy() if $self->{runtime};
     delete $self->{engine};
     delete $self->{runtime};
 }
