@@ -9,9 +9,8 @@ EJS::Template::Parser - Parser module for EJS::Template
 =cut
 
 package EJS::Template::Parser;
-use base 'EJS::Template::Base';
+use base qw(EJS::Template::Base EJS::Template::IO);
 
-use EJS::Template::IO;
 use EJS::Template::Parser::Context;
 
 =head1 Methods
@@ -32,29 +31,21 @@ sub parse {
     my ($in, $in_close) = EJS::Template::IO->input($input);
     
     my $context;
-    
-    eval {
+
+    $self->input($input, sub {
+        my ($in) = @_;
         $context = EJS::Template::Parser::Context->new($self->config);
         
         while (my $line = <$in>) {
             $line =~ s/\r+\n?$/\n/;
             $context->read_line($line);
         }
-    };
-    
-    my $e = $@;
-    close $in if $in_close;
-    die $e if $e;
-    
-    my ($out, $out_close) = EJS::Template::IO->output($output);
-    
-    eval {
+    });
+
+    $self->output($output, sub {
+        my ($out) = @_;
         print $out $_ foreach @{$context->result};
-    };
-    
-    $e = $@;
-    close $out if $out_close;
-    die $e if $e;
+    });
     
     return 1;
 }
